--[[
    BGLive is an user interface for spectated battleground 
	wargames in World of Warcraft.
    Copyright (C) 2015  Harald Böhm <harald@boehm.agency>
	Further contributors: Jochen Taeschner and Romina Schmidt.
	
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	ADDITIONAL PERMISSION UNDER GNU GPL VERSION 3 SECTION 7:
	As a special exception, the copyright holder of this add-on gives you
	permission to link this add-on with independent proprietary software,
	regardless of the license terms of the independent proprietary software.
]]

local addonName, L = ...;
local NameText = ArenaLive:GetHandler("NameText");
local messages = {};

function BGLiveChatMessageFrame:Initialise()
	self.text1.anim:SetScript("OnStop", BGLiveChatMessageFrame.AnimationOnStopOrFinish);
	self.text1.anim:SetScript("OnFinished", BGLiveChatMessageFrame.AnimationOnStopOrFinish);
	self.text1.anim2:SetScript("OnStop", BGLiveChatMessageFrame.AnimationOnStopOrFinish);
	self.text2.anim2:SetScript("OnFinished", BGLiveChatMessageFrame.AnimationOnStopOrFinish);
end

function BGLiveChatMessageFrame:OnEvent(event, ...)
	local msg = ...;
	-- BUGFIX: in Silvershard Mines the word
	-- "Mine Cart" is inserted into the string
	-- from the LUA end, so I've to check, if
	-- the string contains %s.
	if ( BGLive:GetCurrentMapID() == 727 and string.match(msg, "%%s") ) then
		msg = string.format(msg, L["Mine Cart"]);
	end
	local name = select(5, ...);
	local red, green, blue;
	local database = ArenaLive:GetDBComponent(addonName);
	if ( event == "CHAT_MSG_BG_SYSTEM_ALLIANCE" ) then
		red, green, blue = unpack(database.TeamA.Colour);
	elseif ( event == "CHAT_MSG_BG_SYSTEM_HORDE" ) then
		red, green, blue = unpack(database.TeamB.Colour);
	elseif ( event == "CHAT_MSG_BG_SYSTEM_NEUTRAL" or event == "CHAT_MSG_RAID_BOSS_EMOTE" ) then
		red, green, blue = 1, 0.47, 0;
	end
	
	if ( name and name ~= "" ) then
		local nickname = NameText:GetNickname(name);
		if ( nickname ) then
			msg = string.gsub(msg, name, nickname);
		end
	end
	
	if ( self.text1.anim:IsPlaying() ) then
		-- Switch old message to second fontstring object:
		self.text1.anim:Stop();
		local oldMsg = self.text1:GetText();
		local oldRed, oldGreen, oldBlue = self.text1:GetTextColor();
		if ( self.text2.anim2:IsPlaying() ) then
			self.text2.anim2:Stop();
		end
		self.text2:SetTextColor(oldRed, oldGreen, oldBlue, 1);
		self.text2:SetText(oldMsg);
		self.text2:Show();
		self.text2.anim2:Play();
	end
	
	-- Start animation:
	self.text1:SetTextColor(red, green, blue, 1);
	self.text1:SetText(msg);
	self.text1:Show();
	self.text1.anim:Play();

end

function BGLiveChatMessageFrame.AnimationOnStopOrFinish(animation)
	local fontString = animation:GetParent();
	local messageFrame = fontString:GetParent();
	fontString:Hide();
end