--[[
    BGLive is an user interface for spectated battleground 
	wargames in World of Warcraft.
    Copyright (C) 2015  Harald Böhm <harald@boehm.agency>
	Further contributors: Jochen Taeschner and Romina Schmidt.
	
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
	
	ADDITIONAL PERMISSION UNDER GNU GPL VERSION 3 SECTION 7:
	As a special exception, the copyright holder of this add-on gives you
	permission to link this add-on with independent proprietary software,
	regardless of the license terms of the independent proprietary software.
]]

local addonName, L = ...;

local function UpdateBorderColour(self)
	local prefix = self:GetName();
	local border = _G[prefix.."Border"];
	if ( self.unit ) then
		
		local factionGroup = UnitFactionGroup(self.unit);
		local database = ArenaLive:GetDBComponent(addonName);
		local red, green, blue, alpha;
		if ( factionGroup == "Alliance" ) then
			red, green, blue, alpha = unpack(database.TeamA.Colour);
		elseif ( factionGroup == "Horde" ) then
			red, green, blue, alpha = unpack(database.TeamB.Colour);
		else
			red, green, blue, alpha = 1, 1, 1, 1; -- Mostly testing purposes.
		end
		
		border:SetVertexColor(red, green, blue, alpha);
	else
		border:SetVertexColor(1, 1, 1, 1);
	end
end

local function InitialiseSingle(self)
	local prefix = self:GetName();
	self.UpdateBorderColour = UpdateBorderColour;
	ArenaLive:ConstructHandlerObject(self, "UnitFrame", addonName, "SideFrames", "target", nil);
	
	-- Register Frame constituents:
	self:RegisterHandler(_G[prefix.."HealthBar"], "HealthBar", nil, _G[prefix.."HealthBarHealPredictionBar"], _G[prefix.."HealthBarAbsorbBar"], _G[prefix.."HealthBarAbsorbBarOverlay"], 32, _G[prefix.."HealthBarAbsorbBarFullHPIndicator"], nil, addonName, "SideFrames");
		self:RegisterHandler(_G[prefix.."HealthBarText"], "HealthBarText", nil, self);
	self:RegisterHandler(_G[prefix.."Icon"], "Icon", 1, _G[prefix.."IconTexture"],_G[prefix.."IconCooldown"], addonName);
	self:RegisterHandler(_G[prefix.."Name"], "NameText", nil, self);
	self:RegisterHandler(_G[prefix.."Portrait"], "Portrait", nil, _G[prefix.."PortraitBackground"], _G[prefix.."PortraitTexture"],  _G[prefix.."PortraitThreeD"], self);
	self:RegisterHandler(_G[prefix.."PortraitCCIndicator"], "CCIndicator", nil, _G[prefix.."PortraitCCIndicatorTexture"], _G[prefix.."PortraitCCIndicatorCooldown"], addonName);
	self:RegisterHandler(_G[prefix.."PowerBar"], "PowerBar", nil, addonName, "SideFrames");
		self:RegisterHandler(_G[prefix.."PowerBarText"], "PowerBarText", nil, self);
	self:RegisterHandler(_G[prefix.."TargetIndicator"], "TargetIndicator");
	self:RegisterHandler(_G[prefix.."ObjectiveIcon"], "ObjectiveIcon", nil, _G[prefix.."ObjectiveIconTexture"], _G[prefix.."ObjectiveIconText"]);
end

function BGLive:InitialiseCarrierFrames()
	for i = 1, 4 do
		local frame = _G["BGLiveCarrierFramesFrame"..i];
		InitialiseSingle(frame);
	end
end

function BGLive:EnableCarrierFrames()
	for i = 1, 4 do
		local frame = _G["BGLiveCarrierFramesFrame"..i];
		local unit = "arena"..i;
		frame:Enable();
		frame:UpdateUnit(unit);
	end
end

function BGLive:DisableCarrierFrames()
	for i = 1, 4 do
		local frame = _G["BGLiveCarrierFramesFrame"..i];
		frame:Disable();
	end
end

function BGLive:UpdateCarrierFrames()
	for i = 1, 4 do
		local frame = _G["BGLiveCarrierFramesFrame"..i];
		frame:Update();
		frame:UpdateBorderColour();
	end
end